package de.hs_mannheim.informatik.bank.facade;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.Collection;

import de.hs_mannheim.informatik.bank.domain.Bank;
import de.hs_mannheim.informatik.bank.domain.Konto;

public class Banksystem {
	private Bank bank;
	
	public Banksystem(String bankname) {
		this.bank = new Bank(bankname);
	}
	
	public int kontoAnlegen(String name) {
		Konto k = new Konto(name);
		bank.addKonto(k);
		
		return k.getKontonummer();
	}
	
	public String[] getKontenliste() {
		Collection<Konto> konten = bank.getKontenliste();
		String[] liste = new String[konten.size()];
		
		int i = 0;
		for (Konto k : konten) {
			liste[i] = k.toString();
			i++;
		}
		
		return liste;
	}
	
	public String getBankname() {
		return bank.getName();
	}

	public Konto getKonto(int kontoNummer) {
		Collection<Konto> konten = bank.getKontenliste();
		Konto[] kontenArray = konten.toArray(Konto[]::new);
		for (Konto konto : kontenArray) {
			if (konto.getKontonummer() == kontoNummer) {
				return konto;
			}
		}

		return null;
	}

	public String[] getKontoauszug(Konto konto) {
		ArrayList<String> kontoauszug = konto.getKontoauszug();
		String[] auszugArray = new String[kontoauszug.size()];
		int i = 0;
		for (String auszug : kontoauszug) {
			auszugArray[i] = auszug;
			i++;
		}
		return auszugArray;
	}

	public void addGuthaben(Konto konto, int value) {
		konto.addGuthaben(value);
		String bew = createKontoBewegung(konto, value, "+");
		konto.addKontoBewegung(bew);
	}


	public long getGuthaben(Konto konto) {
		return konto.getGuthaben();
	}

	public String createKontoBewegung(Konto konto, int value, String direction) {
		String kontoBewegung = "";

		DateTimeFormatter dtf = DateTimeFormatter.ofPattern("dd/MM/yyyy HH:mm");
		String date = dtf.format(LocalDateTime.now());

		if (direction.equals("+")) {
			kontoBewegung = date + " | " + konto.toString() + " | +" + value + "€";
		} else {
			kontoBewegung = date + " | " + konto.toString() + " | -" + value + "€";
		}

		return kontoBewegung;
	}

	public boolean geldAbheben(Konto konto, int value) {
		if (value <= konto.getGuthaben()) {
			konto.remGuthaben(value);
			String bew = createKontoBewegung(konto, value, "-");
			konto.addKontoBewegung(bew);
		} else {
			return false;
		}
		return true;
	}

}
