package de.hs_mannheim.informatik.bank.ui;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Scanner;

import de.hs_mannheim.informatik.bank.domain.Konto;
import de.hs_mannheim.informatik.bank.facade.Banksystem;
import de.hs_mannheim.informatik.bank.domain.Bank;

public class UI {
	private Banksystem bs;
	Scanner sc = new Scanner(System.in);

	public UI(Banksystem bs) {
		this.bs = bs;
		hauptmenü();
	}

	private void hauptmenü() {
		System.out.println("Willkommen bei der " + bs.getBankname() + "!");

		mainloop:
			while (true) {
				System.out.println();
				System.out.println("--------");
				System.out.println("Hauptmenü");
				System.out.println("1 -> Konten anzeigen");
				System.out.println("2 -> Konto anlegen");
				System.out.println("3 -> Geld einzahlen");
				System.out.println("4 -> Geld auszahlen");
				System.out.println("5 -> Guthaben ausgeben");
				System.out.println("6 -> Kontoauszug ausgeben");
				System.out.println("9 -> Beenden");
				System.out.println();

				System.out.print("> ");

				int input = 0;
				try {
					input = Integer.parseInt(sc.nextLine());
				} catch (Exception e) {
					System.out.println(e);
				}
				System.out.println();

				switch(input) {
					case 1 -> kontenAnzeigen();
					case 2 -> kontoAnlegen();
					case 3 -> kontoAufladen();
					case 4 -> geldAuszahlen();
					case 5 -> guthabenAusgeben();
					case 6 -> kontoauszug();
					case 9 -> {
						break mainloop;
					}
				}
			}

		System.out.println("Auf Wiedersehen!");

	} // hauptmenü

	private void guthabenAusgeben() {
		Konto konto = selectKonto();

		System.out.println("\nIhr aktuelles Guthaben ist: ");
		System.out.print(bs.getGuthaben(konto));
		System.out.println("€");
	}

	private void geldAuszahlen() {
		Konto konto = selectKonto();

		System.out.println("Wieviel Euro möchten Sie abheben?");

		int input = getInt();

		Boolean auszahlung = bs.geldAbheben(konto, input);

		if (!auszahlung) {
			System.out.println("Ihr Guthaben reicht für diese Auszahlung nicht mehr aus!");
			System.out.println("Ihr Kontostand ist aktuell " + bs.getGuthaben(konto) + "€ und Sie wollten " + input + "€ auszahlen lassen!");
		} else {
			System.out.println("Sie haben sich erfolgreich " + input + "€ ausgezahlt!");
		}

	}

	private void kontoAufladen() {
		Konto konto = selectKonto();

		if (konto != null) {
			System.out.println("Wieviel möchten sie aufladen? (nur ganze Beträge)!");
			System.out.print("> ");

			int input = 0;

			try {
				input = Integer.parseInt(sc.nextLine());
			} catch (Exception e) {
				System.out.println("Bitte geben Sie einen gültigen Betrag ein!");
				kontoAufladen();
			}

			if (input != 0) {
				bs.addGuthaben(konto, input);
				System.out.println("\n" + input + "€ wurden aufgeladen!");
				System.out.println("Ihr aktueller Kontostand beträgt " + konto.getGuthaben() + "€");
				System.out.println("Drücken Sie ENTER um zum Hauptmenu zurück zu kehren!");
				sc.nextLine();
			}
		}

	}

	private Konto selectKonto() {
		System.out.println("Bitte geben Sie die Kontonummer ihres Kontos an: ");

//		kontenAnzeigen();

		System.out.print("\n> ");
		int input = 0;
		try {
			input = Integer.parseInt(sc.nextLine());

		} catch (Exception e) {
//			System.out.println("An Error occured: " + e);
		};

		Konto konto = bs.getKonto(input);

		if (konto == null) {
			System.out.println("Die angegebene Kontonummer existiert nicht!");
		}

		return konto;
	}

	private void kontenAnzeigen() {		
		String[] konten = bs.getKontenliste();
		if (konten.length > 0) {
			System.out.println("Folgende Konten sind aktuell verfügbar:");
			int i = 1;
			for (String s : konten) {
				System.out.println(i + ": " + s);
				i++;
			}
		} else {
			System.out.println("Bisher keine Konten angelegt.");
		}
	}

	public void kontoauszug() {
		Konto konto = selectKonto();

		String[] kontoauszug = bs.getKontoauszug(konto);
		for (String k : kontoauszug) {
			System.out.println(k);
		}
	}

	private void kontoAnlegen() {
		System.out.println("Bitte den Namen des Kontoinhabers angeben: ");
		String name = sc.nextLine();

		int kontonummer = bs.kontoAnlegen(name);
		System.out.println("Konto mit der Nummer " + kontonummer + " neu angelegt.");
	}

	private int getInt() {
		int input = 0;
		try {
			input = Integer.parseInt(sc.nextLine());
		} catch (Exception e) {
			System.out.println("Bitte geben Sie einen gültigen Betrag ein!");
			kontoAufladen();
		}
		return input;
	}

}
